@@ -206,7 +206,10 @@ def patch_instance(entity_instance_id: str, if_match: str, patch: Mapping[str, A
                    request_mode: Union[None, str, RequestMode] = None) -> PatchResponse:
     uri = _build_instance_or_collection_uri(entity_instance_id).to_text()
     auth = get_request_auth()
-    headers = {HttpHeaders.IF_MATCH: if_match}
+    headers = {
+        HttpHeaders.IF_MATCH: if_match,
+        HttpHeaders.CONTENT_TYPE: "application/merge-patch+json; charset=UTF-8"
+    }
     params: MutableMapping[str, Sequence[str]] = {}
     _add_mode_param(params, request_mode)
     response = _handle_response(lambda: requests.patch(uri, auth=auth, headers=headers, json=patch, params=params),
